@@ -95,3 +95,37 @@ def circumference2(d):
     _if_not_int_or_float_raise(d)
     _if_not_positive_raise(d)
     return _pi * d
+
+def area_of_sector(r, a):
+    """A function that calculates the area of a sector in a circle:
+      angle/360 * \u03C0 * (r squared)
+
+    Parameters
+    ----------
+    r: int or float
+      The radius in the equation.
+
+    a: int or float
+      The angle in the equation.
+
+    Returns
+    -------
+      Float
+          a/360 * \u03C0 * r**2
+
+    Raises
+    ------
+    ValueError
+      If a or r::
+          Is not an integer or float.
+          Is not positive.
+
+    Examples
+    --------
+    >>> school_algorithms.circumference(5, 40)
+    8.7266462599717
+
+    """
+    _if_not_int_or_float_raise(r, a)
+    _if_not_positive_raise(r, a)
+    return a/360 * _pi * r**2
